@@ -4,7 +4,7 @@
   CLAW is a free library without any particular aim but being useful to 
   anyone.
 
-  Copyright (C) 2005-2008 Julien Jorge
+  Copyright (C) 2005-2010 Julien Jorge
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -75,6 +75,8 @@ namespace claw
       bool includes( const self_type& r ) const;
       bool intersects( const self_type& r ) const;
       self_type intersection( const self_type& r ) const;
+      self_type join( const self_type& r ) const;
+      bool empty() const;
 
       value_type top() const;
       value_type bottom() const;
