@@ -4,7 +4,7 @@
   CLAW is a free library without any particular aim but being useful to 
   anyone.
 
-  Copyright (C) 2005-2008 Julien Jorge
+  Copyright (C) 2005-2010 Julien Jorge
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -27,8 +27,12 @@
  * \brief Implementation of the claw::application class.
  * \author Julien Jorge
  */
-#include "claw/application.hpp"
+#include <claw/application.hpp>
+
 #include <claw/logger.hpp>
+#include <claw/log_stream_uniq.hpp>
+#include <claw/log_stream_concise.hpp>
+#include <claw/claw_gettext.hpp>
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -42,33 +46,59 @@
 claw::application::application( int& argc, char** &argv )
   : m_arguments( argc, argv )
 {
-  m_arguments.add_long("--log-file",
-                       "The file to use to store log informations.", true,
-                       "file" );
-  m_arguments.add_long("--log-level",
-                       "Level of log informations:\n"
-		       "\t\terror: error messages,\n"
-                       "\t\twarning: warning and error messages,\n"
-                       "\t\tverbose: all messages.", true, "string" );
+  setlocale( LC_ALL, "" );
+  bind_textdomain_codeset( "libclaw", "UTF-8" );
+  textdomain("libclaw");
+
+  m_arguments.add_long
+    ("--log-file", claw_gettext("The file to use to store log informations."),
+     true, claw_gettext("file") );
+  m_arguments.add_long
+    ("--log-level",
+     claw_gettext("Level of log informations:\n"
+		  "\t\terror: error messages,\n"
+		  "\t\twarning: warning and error messages,\n"
+		  "\t\tverbose: all messages."), true, claw_gettext("string") );
+  m_arguments.add_long
+    ("--log-uniq",
+     claw_gettext
+     ("Use a logger that does not output successively the same message."),
+     true );
+  m_arguments.add_long
+    ("--log-concise",
+     claw_gettext
+     ("Use a logger that does not output messages that have been recently"
+      " output."), true, claw_gettext("integer") );
+
   m_arguments.parse( argc, argv );
+  
+  log_stream* log;
 
   if ( m_arguments.has_value("--log-file") )
-    {
-      std::string log_file = m_arguments.get_string("--log-file");
-      logger.set( new file_logger(log_file) );
-    }
+    log = new file_logger( m_arguments.get_string("--log-file") );
   else
-    logger.set( new console_logger() );
+    log = new console_logger;
+
+  if ( m_arguments.get_bool("--log-uniq") )
+    log = new log_stream_uniq(log);
+  else if ( m_arguments.has_value("--log-concise")
+	    && m_arguments.only_integer_values("--log-concise")
+	    && m_arguments.get_integer("--log-concise") > 0 )
+    log = new log_stream_concise(log, m_arguments.get_integer("--log-concise"));
+  else if ( m_arguments.get_bool("--log-concise") )
+    log = new log_stream_concise(log);
+ 
+  logger.set( log );
 
   if ( m_arguments.has_value( "--log-level" ) )
     {
       std::string level = m_arguments.get_string("--log-level");
 
-      if (level == "error")
+      if ( (level == "error") || (level == claw_gettext("error")) )
 	logger.set_level( log_error );
-      else if (level == "warning")
+      else if ( (level == "warning") || (level == claw_gettext("warning")) )
 	logger.set_level( log_warning );
-      else if (level == "verbose")
+      else if ( (level == "verbose") || (level == claw_gettext("verbose")) )
 	logger.set_level( log_verbose );
       else
 	logger.set_level( m_arguments.get_integer("--log-level") );
