@@ -4,7 +4,7 @@
   CLAW is a free library without any particular aim but being useful to 
   anyone.
 
-  Copyright (C) 2005-2008 Julien Jorge
+  Copyright (C) 2005-2010 Julien Jorge
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -32,13 +32,14 @@
 #include <sstream>
 #include <claw/assert.hpp>
 #include <claw/string_algorithm.hpp>
+#include <claw/claw_gettext.hpp>
 
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
  */
 claw::arguments::arguments()
-  : m_program_name("<unknow>")
+  : m_program_name( claw_gettext("<unknow>") )
 {
 
 } // arguments::arguments()
@@ -132,15 +133,13 @@ bool claw::arguments::has_value( const std::string& arg_name ) const
 bool claw::arguments::only_integer_values( const std::string& arg_name ) const
 {
   const valued_arguments_map::const_iterator itk(m_pairs.find(arg_name));
-  bool result;
+  bool result = true;
 
   if ( itk == m_pairs.end() )
     result = false;
   else
     {
       std::list<std::string>::const_iterator it;
-      result = true;
-
       for( it=itk->second.begin(); result && (it!=itk->second.end()); ++it )
         result = result && text::is_of_type<int>(*it);
     }
@@ -156,15 +155,13 @@ bool claw::arguments::only_integer_values( const std::string& arg_name ) const
 bool claw::arguments::only_real_values( const std::string& arg_name ) const
 {
   const valued_arguments_map::const_iterator itk(m_pairs.find(arg_name));
-  bool result;
+  bool result = true;
 
   if ( itk == m_pairs.end() )
     result = false;
   else
     {
       std::list<std::string>::const_iterator it;
-      result = true;
-
       for( it=itk->second.begin(); result && (it!=itk->second.end()); ++it )
         result = result && text::is_of_type<double>(*it);
     }
