@@ -4,7 +4,7 @@
   CLAW is a free library without any particular aim but being useful to 
   anyone.
 
-  Copyright (C) 2005-2008 Julien Jorge
+  Copyright (C) 2005-2010 Julien Jorge
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -250,7 +250,7 @@ void claw::arguments_table::help( const std::string& free_args ) const
     if ( it->is_optional() )
       optional.push_back(it);
     else
-      std::cout << " " << it->format_short_help();
+      std::cout << ' ' << it->format_short_help();
 
   for (it=m_long_arguments.begin(); it!=m_long_arguments.end(); ++it)
     if (it->get_second_name().empty())
@@ -258,14 +258,14 @@ void claw::arguments_table::help( const std::string& free_args ) const
 	if ( it->is_optional() )
 	  optional.push_back(it);
 	else
-	  std::cout << " " << it->format_short_help();
+	  std::cout << ' ' << it->format_short_help();
       }
 
   for (it_opt=optional.begin(); it_opt!=optional.end(); ++it_opt)
-    std::cout << " " << (*it_opt)->format_short_help();
+    std::cout << ' ' << (*it_opt)->format_short_help();
 
   if ( !free_args.empty() )
-    std::cout << " " << free_args;
+    std::cout << ' ' << free_args;
 
   std::cout << "\n\n";
 
