@@ -4,7 +4,7 @@
   CLAW is a free library without any particular aim but being useful to 
   anyone.
 
-  Copyright (C) 2005-2008 Julien Jorge
+  Copyright (C) 2005-2010 Julien Jorge
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -227,7 +227,7 @@ bool claw::graphic::pcx::reader::rle_pcx_output_buffer::completed() const
  * \param output The output stream (the pcx image).
  */
 void claw::graphic::pcx::reader::rle_pcx_decoder::read_mode
-( rle_pcx_input_buffer& input, rle_pcx_output_buffer& output )
+( input_buffer_type& input, output_buffer_type& output )
 {
   this->m_mode = this->stop;
   bool ok = !output.completed();
