@@ -4,7 +4,7 @@
   CLAW is a free library without any particular aim but being useful to 
   anyone.
 
-  Copyright (C) 2005-2008 Julien Jorge
+  Copyright (C) 2005-2010 Julien Jorge
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -146,7 +146,7 @@ void claw::graphic::png::reader::read_from_file( std::istream& f )
     {
       /* If we get here, we had a problem reading the file */
       /* Free all of the memory associated with the png_ptr and info_ptr */
-      png_destroy_read_struct(&png_ptr, &info_ptr, png_infopp_NULL);
+      png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp)NULL);
       throw CLAW_EXCEPTION("Invalid PNG file.");
     }
       
@@ -156,7 +156,7 @@ void claw::graphic::png::reader::read_from_file( std::istream& f )
                    claw__graphic__png__source_manager__read );
 
   png_set_strip_16(png_ptr);
-  png_set_gray_1_2_4_to_8(png_ptr);
+  png_set_expand_gray_1_2_4_to_8(png_ptr);
   png_set_packing(png_ptr);
 
   // transform palette index into RGB value
@@ -170,7 +170,7 @@ void claw::graphic::png::reader::read_from_file( std::istream& f )
   png_read_info(png_ptr, info_ptr);
   read_image( png_ptr, info_ptr );
       
-  png_destroy_read_struct(&png_ptr, &info_ptr, png_infopp_NULL);
+  png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp)NULL);
 } // png::reader::read_from_file()
 
 /*----------------------------------------------------------------------------*/
@@ -340,7 +340,7 @@ void claw::graphic::png::reader::create_read_structures
       info_ptr = png_create_info_struct(png_ptr);
 
       if (!info_ptr)
-        png_destroy_read_struct(&png_ptr, png_infopp_NULL, png_infopp_NULL);
+        png_destroy_read_struct(&png_ptr, (png_infopp)NULL, (png_infopp)NULL);
     }
 
   if (!png_ptr || !info_ptr)
