@@ -4,7 +4,7 @@
   CLAW is a free library without any particular aim but being useful to 
   anyone.
 
-  Copyright (C) 2005-2008 Julien Jorge
+  Copyright (C) 2005-2010 Julien Jorge
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -144,7 +144,7 @@ void claw::graphic::xbm::reader::read_from_file( std::istream& f )
     }
 
   if ( !valid_format )
-    throw CLAW_EXCEPTION( "Not a XBM file." );
+    throw claw::exception( "Not an XBM file." );
 } // xbm::reader::read_from_file()
 
 /*----------------------------------------------------------------------------*/
@@ -198,7 +198,7 @@ void claw::graphic::xbm::reader::read_size( std::istream& f )
   if ( valid )
     m_image.set_size(w, h);
   else
-    throw CLAW_EXCEPTION( "Not a XBM file." );
+    throw claw::exception( "Not an XBM file." );
 } // xbm::reader::read_size()
 
 /*----------------------------------------------------------------------------*/
@@ -221,7 +221,7 @@ claw::graphic::xbm::reader::read_dim( const std::string& line ) const
           valid = true;
 
   if ( !valid )
-    throw CLAW_EXCEPTION( "Not a XBM file." );
+    throw claw::exception( "Not an XBM file." );
 
   return result;
 } // xbm::reader::read_dim()
@@ -259,7 +259,7 @@ claw::graphic::xbm::reader::read_bits_per_entry( std::istream& f ) const
         }
 
   if ( result == 0 )
-    throw CLAW_EXCEPTION( "Not a XBM file." );
+    throw claw::exception( "Not an XBM file." );
 
   return result;
 } // xbm::reader::read_bits_per_entry()
@@ -293,7 +293,7 @@ void claw::graphic::xbm::reader::read_name( std::istream& f )
     }
 
   if ( !valid )
-    throw CLAW_EXCEPTION( "Not a XBM file." );
+    throw claw::exception( "Not an XBM file." );
 } // xbm::reader::read_name()
 
 /*----------------------------------------------------------------------------*/
@@ -338,7 +338,7 @@ void claw::graphic::xbm::reader::read_pixels
     }
 
   if ( !valid )
-    throw CLAW_EXCEPTION( "Not a XBM file." );
+    throw claw::exception( "Not an XBM file." );
 } // xbm::reader::read_pixels()
 
 /*----------------------------------------------------------------------------*/
