@@ -4,7 +4,7 @@
   CLAW is a free library without any particular aim but being useful to 
   anyone.
 
-  Copyright (C) 2005-2008 Julien Jorge
+  Copyright (C) 2005-2010 Julien Jorge
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -30,7 +30,7 @@
 #ifndef __CLAW_GRAPH_HPP__
 #define __CLAW_GRAPH_HPP__
 
-#include <claw/meta.hpp>
+#include <claw/meta/no_type.hpp>
 
 #include <map>
 #include <vector>
