@@ -4,7 +4,7 @@
   CLAW is a free library without any particular aim but being useful to 
   anyone.
 
-  Copyright (C) 2005-2008 Julien Jorge
+  Copyright (C) 2005-2010 Julien Jorge
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -54,7 +54,8 @@ namespace claw
        * \brief One line in the image.
        * \author Julien Jorge
        */
-      class scanline : private std::vector<pixel_type>
+      class scanline:
+        private std::vector<pixel_type>
       {
         friend class image;
 
@@ -100,8 +101,8 @@ namespace claw
        * \author Julien Jorge.
        */
       template<typename Image, typename Pixel>
-      class base_iterator
-        : public std::iterator<std::random_access_iterator_tag, Pixel>
+      class base_iterator:
+        public std::iterator<std::random_access_iterator_tag, Pixel>
       {
       private:
         /** \brief The type of the image we are iterating through. */
@@ -174,7 +175,8 @@ namespace claw
       image();
       image( unsigned int w, unsigned int h );
       image( std::istream& f );
-      virtual ~image();
+
+      void swap( image& that );
 
       unsigned int width() const;
       unsigned int height() const;
@@ -187,10 +189,15 @@ namespace claw
       const_iterator begin() const;
       const_iterator end() const;
 
-      void partial_copy( const image& that,
-                         const claw::math::coordinate_2d<int>& pos );
+      void merge( const image& that );
+      void merge
+      ( const image& that, const math::coordinate_2d<int>& pos );
+
+      void partial_copy
+      ( const image& that, const math::coordinate_2d<int>& pos );
 
       void flip();
+      void fill( const math::rectangle<int> r, const pixel_type& c );
 
       void set_size( unsigned int w, unsigned int h );
 
@@ -205,6 +212,11 @@ namespace claw
   } // namespace graphic
 } // namespace claw
 
+namespace std
+{
+  void swap( claw::graphic::image& a, claw::graphic::image& b );
+} // namespace std
+
 // Inline methods
 #include <claw/impl/image.ipp>
 
