@@ -4,7 +4,7 @@
   CLAW is a free library without any particular aim but being useful to 
   anyone.
 
-  Copyright (C) 2005-2008 Julien Jorge
+  Copyright (C) 2005-2010 Julien Jorge
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -38,15 +38,19 @@
 #include <claw/log_stream.hpp>
 
 #ifndef CLAW_LOGGER_EXPORT
-#  ifdef _WIN32
-#    ifdef claw_logger_EXPORTS
-#      define CLAW_LOGGER_EXPORT __declspec(dllexport)
-#    else
-#      define CLAW_LOGGER_EXPORT __declspec(dllimport)
-#    endif // def claw_logger_EXPORTS
-#  else // def _WIN32
+#  ifdef CLAW_LOGGER_NO_EXPORT
 #    define CLAW_LOGGER_EXPORT
-#  endif // def _WIN32
+#  else
+#    ifdef _WIN32
+#      ifdef claw_logger_EXPORTS
+#        define CLAW_LOGGER_EXPORT __declspec(dllexport)
+#      else
+#        define CLAW_LOGGER_EXPORT __declspec(dllimport)
+#      endif // def claw_logger_EXPORTS
+#    else // def _WIN32
+#      define CLAW_LOGGER_EXPORT
+#    endif // def _WIN32
+#  endif // def CLAW_LOGGER_NO_EXPORT
 #endif // ndef CLAW_LOGGER_EXPORT
 
 namespace claw
