@@ -4,7 +4,7 @@
   CLAW is a free library without any particular aim but being useful to 
   anyone.
 
-  Copyright (C) 2005-2008 Julien Jorge
+  Copyright (C) 2005-2010 Julien Jorge
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -32,10 +32,11 @@
 
 namespace claw
 {
-  namespace concept
+  namespace pattern
   {
     /**
-     * \brief Inherit from this class to forbid copy constructor in your class.
+     * \brief Inherit from this class to forbid construction of your class by
+     *        copy.
      * \author Julien Jorge
      */
     class non_copyable
@@ -46,19 +47,22 @@ namespace claw
       
     private:
       /**
-       * \brief Copy constructor is private.
+       * \brief Copy constructor is declared private and non implemented.
        * \param that Instance to copy from.
        */
-      non_copyable( const non_copyable& that ) {}
+      non_copyable( const non_copyable& that );
 
       /**
-       * \brief Assignment operator is private.
+       * \brief Assignment operator is declared private and non implemented.
        * \param that Instance to copy from.
        */
-      non_copyable& operator=( const non_copyable& that ) { return *this; }
+      non_copyable& operator=( const non_copyable& that );
       
     }; // non_copyable
-  } // namespace concept
+  } // namespace pattern
+
+  namespace concept = pattern;
+
 } // namespace claw
 
 #endif // __CLAW_NON_COPYABLE_HPP__
