@@ -4,7 +4,7 @@
   CLAW is a free library without any particular aim but being useful to 
   anyone.
 
-  Copyright (C) 2005-2008 Julien Jorge
+  Copyright (C) 2005-2010 Julien Jorge
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -34,7 +34,7 @@ namespace claw
 {
   namespace graphic
   {
-    union rgba_pixel;
+    struct rgba_pixel;
 
     /**
      * \brief RGB pixel.
@@ -72,32 +72,36 @@ namespace claw
     /**
      * \brief RGBA pixel.
      */
-    union rgba_pixel
+    struct rgba_pixel
     {
       typedef unsigned char component_type;
 
-      /** \brief Compressed representation. */
-      unsigned int pixel;
-
-      /** \brief Component by component representation. */
-      struct
+      union
       {
-        /** \brief Red component. */
-        component_type red;
+	/** \brief Compressed representation. */
+	unsigned int pixel;
 
-        /** \brief Green component. */
-        component_type green;
+	/** \brief Component by component representation. */
+	struct
+	{
+	  /** \brief Red component. */
+	  component_type red;
 
-        /** \brief Blue component. */
-        component_type blue;
+	  /** \brief Green component. */
+	  component_type green;
 
-        /** \brief Translucy. */
-        component_type alpha;
+	  /** \brief Blue component. */
+	  component_type blue;
 
-      } components; 
+	  /** \brief Translucy. */
+	  component_type alpha;
+
+	} components;
+      };
 
     public:
       rgba_pixel();
+      rgba_pixel( const rgb_pixel& that );
       rgba_pixel( component_type r, component_type g, component_type b,
                   component_type a );
 
@@ -112,6 +116,8 @@ namespace claw
     typedef rgb_pixel rgb_pixel_8;
     typedef rgba_pixel rgba_pixel_8;
 
+    extern rgba_pixel transparent_pixel;
+
     extern rgba_pixel black_pixel;
     extern rgba_pixel white_pixel;
 
