@@ -4,7 +4,7 @@
   CLAW is a free library without any particular aim but being useful to 
   anyone.
 
-  Copyright (C) 2005-2008 Julien Jorge
+  Copyright (C) 2005-2010 Julien Jorge
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -85,9 +85,9 @@ namespace claw
       bool operator>=( const self_type& that ) const;
 
       pointer operator->();
-      const_pointer operator->() const;
+      pointer operator->() const;
       reference operator*();
-      const_reference operator*() const;
+      reference operator*() const;
 
     private:
       void copy( const self_type& that );
